function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { useState } from 'react';
import Checkbox from './Checkbox';
var meta = {
  title: 'Example/Checkbox',
  component: Checkbox
};
export default meta;
// Basic checkbox
export var Default = {
  args: {
    name: 'default-checkbox',
    value: 'default',
    label: 'Default checkbox'
  },
  parameters: {
    docs: {
      description: {
        story: 'The default checkbox in its unchecked state.'
      }
    }
  }
}; // Checked checkbox

export var Checked = {
  args: {
    name: 'checked-checkbox',
    value: 'checked',
    label: 'Checked checkbox',
    checked: true
  },
  parameters: {
    docs: {
      description: {
        story: 'A checkbox in its checked state.'
      }
    }
  }
}; // Indeterminate checkbox

export var Indeterminate = {
  args: {
    name: 'indeterminate-checkbox',
    value: 'indeterminate',
    label: 'Indeterminate checkbox',
    indeterminate: true
  },
  parameters: {
    docs: {
      description: {
        story: 'A checkbox in its indeterminate state, useful for representing partially selected states.'
      }
    }
  }
}; // Disabled checkbox

export var Disabled = {
  args: {
    name: 'disabled-checkbox',
    value: 'disabled',
    label: 'Disabled checkbox',
    disabled: true
  },
  parameters: {
    docs: {
      description: {
        story: 'A disabled checkbox that cannot be interacted with.'
      }
    }
  }
}; // Invalid checkbox

export var Invalid = {
  args: {
    name: 'invalid-checkbox',
    value: 'invalid',
    label: 'Invalid checkbox',
    invalid: true
  },
  parameters: {
    docs: {
      description: {
        story: 'A checkbox marked as invalid, typically used to indicate validation errors.'
      }
    }
  }
}; // No label checkbox

export var NoLabel = {
  args: {
    name: 'nolabel-checkbox',
    value: 'nolabel',
    noLabel: true
  },
  parameters: {
    docs: {
      description: {
        story: 'A checkbox without a label.'
      }
    }
  }
}; // Custom size checkbox

export var CustomSize = {
  args: {
    name: 'customsize-checkbox',
    value: 'customsize',
    label: 'Custom size checkbox (24px)',
    size: 24
  },
  parameters: {
    docs: {
      description: {
        story: 'A checkbox with a custom size (larger than default).'
      }
    }
  }
}; // Custom spacing checkbox

export var CustomSpacing = {
  args: {
    name: 'customspacing-checkbox',
    value: 'customspacing',
    label: 'Custom spacing checkbox',
    spacing: 8
  },
  parameters: {
    docs: {
      description: {
        story: 'A checkbox with custom spacing between the checkbox and its label.'
      }
    }
  }
}; // Interactive checkbox example

var InteractiveCheckbox = () => {
  var [checked, setChecked] = useState(false);
  return /*#__PURE__*/React.createElement(Checkbox, {
    name: "interactive-checkbox",
    value: "interactive",
    label: "Interactive checkbox (".concat(checked ? 'checked' : 'unchecked', ")"),
    checked: checked,
    onChange: e => setChecked(e.target.checked)
  });
};

export var Interactive = {
  render: () => /*#__PURE__*/React.createElement(InteractiveCheckbox, null),
  parameters: {
    docs: {
      description: {
        story: 'An interactive checkbox that updates its label based on its state.'
      }
    }
  }
}; // Checkbox group example

var CheckboxGroupExample = () => {
  var [selectedOptions, setSelectedOptions] = useState([]);

  var handleChange = e => {
    var value = e.target.value;

    if (e.target.checked) {
      setSelectedOptions([...selectedOptions, value]);
    } else {
      setSelectedOptions(selectedOptions.filter(option => option !== value));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    style: {
      display: 'flex',
      flexDirection: 'column',
      gap: '12px'
    }
  }, /*#__PURE__*/React.createElement("div", null, "Selected options: ", selectedOptions.join(', ') || 'None'), /*#__PURE__*/React.createElement(Checkbox, {
    name: "options",
    value: "option1",
    label: "Option 1",
    checked: selectedOptions.includes('option1'),
    onChange: handleChange
  }), /*#__PURE__*/React.createElement(Checkbox, {
    name: "options",
    value: "option2",
    label: "Option 2",
    checked: selectedOptions.includes('option2'),
    onChange: handleChange
  }), /*#__PURE__*/React.createElement(Checkbox, {
    name: "options",
    value: "option3",
    label: "Option 3",
    checked: selectedOptions.includes('option3'),
    onChange: handleChange
  }));
};

export var CheckboxGroup = {
  render: () => /*#__PURE__*/React.createElement(CheckboxGroupExample, null),
  parameters: {
    docs: {
      description: {
        story: 'A group of checkboxes working together to select multiple options.'
      }
    }
  }
}; // Indeterminate Parent-Child Example

var ParentChildCheckboxes = () => {
  var [parentChecked, setParentChecked] = useState(false);
  var [parentIndeterminate, setParentIndeterminate] = useState(false);
  var [children, setChildren] = useState({
    child1: false,
    child2: false,
    child3: false
  });

  var updateParentState = newChildren => {
    var checkedCount = Object.values(newChildren).filter(Boolean).length;
    setParentIndeterminate(checkedCount > 0 && checkedCount < Object.keys(newChildren).length);
    setParentChecked(checkedCount === Object.keys(newChildren).length);
  };

  var handleParentChange = e => {
    var newChecked = e.target.checked;
    setParentChecked(newChecked);
    setParentIndeterminate(false);
    var newChildren = {
      child1: newChecked,
      child2: newChecked,
      child3: newChecked
    };
    setChildren(newChildren);
  };

  var handleChildChange = e => {
    var {
      name,
      checked
    } = e.target;

    var newChildren = _objectSpread(_objectSpread({}, children), {}, {
      [name]: checked
    });

    setChildren(newChildren);
    updateParentState(newChildren);
  };

  return /*#__PURE__*/React.createElement("div", {
    style: {
      display: 'flex',
      flexDirection: 'column',
      gap: '8px'
    }
  }, /*#__PURE__*/React.createElement(Checkbox, {
    name: "parent",
    value: "parent",
    label: "Select All",
    checked: parentChecked,
    indeterminate: parentIndeterminate,
    onChange: handleParentChange
  }), /*#__PURE__*/React.createElement("div", {
    style: {
      marginLeft: '24px',
      display: 'flex',
      flexDirection: 'column',
      gap: '8px'
    }
  }, /*#__PURE__*/React.createElement(Checkbox, {
    name: "child1",
    value: "child1",
    label: "Item 1",
    checked: children.child1,
    onChange: handleChildChange
  }), /*#__PURE__*/React.createElement(Checkbox, {
    name: "child2",
    value: "child2",
    label: "Item 2",
    checked: children.child2,
    onChange: handleChildChange
  }), /*#__PURE__*/React.createElement(Checkbox, {
    name: "child3",
    value: "child3",
    label: "Item 3",
    checked: children.child3,
    onChange: handleChildChange
  })));
};

export var ParentChildExample = {
  render: () => /*#__PURE__*/React.createElement(ParentChildCheckboxes, null),
  parameters: {
    docs: {
      description: {
        story: 'A parent checkbox with indeterminate state that controls multiple child checkboxes.'
      }
    }
  }
};